@@ -8,6 +8,8 @@ def apply(loop=None):
     Patch asyncio to make its event loop reentrent.
     """
     loop = loop or asyncio.get_event_loop()
+    if not isinstance(loop, asyncio.BaseEventLoop):
+        raise ValueError('Can\'t patch loop of type %s' % type(loop))
     if hasattr(loop, '_run_until_complete_orig'):
         # already patched
         return
